@@ -16,6 +16,7 @@ typedef enum cffi_enumdocumented
     } cffi_enumdocumented;
 
 typedef struct cffi_context cffi_context;
+typedef struct cffi_generic2u8 cffi_generic2u8;
 typedef struct cffi_opaque cffi_opaque;
 typedef struct cffi_simpleservice cffi_simpleservice;
 typedef struct cffi_empty cffi_empty;
@@ -85,6 +86,8 @@ typedef struct cffi_vec3f32
 
 typedef uint8_t (*cffi_fptr_fn_u8_rval_u8)(uint8_t x0);
 
+typedef uint32_t (*cffi_fptr_fn_u32_rval_u32)(uint32_t x0);
+
 typedef struct cffi_genericu32
     {
     uint32_t* x;
@@ -123,14 +126,16 @@ typedef struct cffi_myapiv1
     cffi_fptr_fn_Tupled_rval_Tupled tupled;
     } cffi_myapiv1;
 
-typedef uint8_t (*cffi_fptr_fn_FFISliceu8_rval_u8)(cffi_ffisliceu8 x0);
-
 typedef struct cffi_ffislicevec3f32
     {
     cffi_vec3f32* data;
     uint64_t len;
     } cffi_ffislicevec3f32;
 
+typedef uint8_t (*cffi_fptr_fn_FFISliceu8_rval_u8)(cffi_ffisliceu8 x0);
+
+typedef cffi_vec3f32 (*cffi_fptr_fn_FFISliceVec3f32_rval_Vec3f32)(cffi_ffislicevec3f32 x0);
+
 
 void primitive_void();
 void primitive_void2();
@@ -158,6 +163,7 @@ cffi_opaque* complex_args_2(cffi_someforeigntype _cmplx);
 uint8_t callback(cffi_fptr_fn_u8_rval_u8 callback, uint8_t value);
 uint32_t generic_1(cffi_genericu32 x, cffi_phantomu8 _y);
 uint8_t generic_2(cffi_genericu8 x, cffi_phantomu8 _y);
+uint8_t generic_3(cffi_generic2u8* x);
 cffi_enumdocumented documented(cffi_structdocumented _x);
 cffi_vec1 ambiguous_1(cffi_vec1 x);
 cffi_vec2 ambiguous_2(cffi_vec2 x);
@@ -170,9 +176,11 @@ uint32_t pattern_ascii_pointer_len(uint8_t* x, cffi_useasciistringpattern y);
 uint32_t pattern_ffi_slice_1(cffi_ffisliceu32 ffi_slice);
 cffi_vec3f32 pattern_ffi_slice_2(cffi_ffislicevec3f32 ffi_slice, int32_t i);
 uint8_t pattern_ffi_slice_delegate(cffi_fptr_fn_FFISliceu8_rval_u8 callback);
+cffi_vec3f32 pattern_ffi_slice_delegate_huge(cffi_fptr_fn_FFISliceVec3f32_rval_Vec3f32 callback);
 cffi_ffioptioninner pattern_ffi_option_1(cffi_ffioptioninner ffi_slice);
 cffi_inner pattern_ffi_option_2(cffi_ffioptioninner ffi_slice);
 void my_api_init_v1(cffi_myapiv1* api);
+uint32_t pattern_callback_1(cffi_fptr_fn_u32_rval_u32 callback, uint32_t x);
 cffi_ffierror pattern_service_create(cffi_context** context_ptr, uint32_t value);
 cffi_ffierror pattern_service_destroy(cffi_context** context_ptr);
 uint32_t pattern_service_method(cffi_context* context);
@@ -603,6 +611,8 @@ class callbacks:
     fn_pmut_i64_rval_bool = "bool(int64_t*)"
     fn_u8_rval_u8 = "uint8_t(uint8_t)"
     fn_FFISliceu8_rval_u8 = "uint8_t(cffi_ffisliceu8)"
+    fn_FFISliceVec3f32_rval_Vec3f32 = "cffi_vec3f32(cffi_ffislicevec3f32)"
+    fn_u32_rval_u32 = "uint32_t(uint32_t)"
 
 
 
@@ -823,6 +833,13 @@ Parameter x must point to valid data."""
             _y = _y._ctx[0]
         return _api.generic_2(x, _y)
 
+    def generic_3(x):
+        """"""
+        global _api
+        if hasattr(x, "_ctx"):
+            x = x._ctx[0]
+        return _api.generic_3(x)
+
     def documented(_x):
         """This function has documentation."""
         global _api
@@ -911,6 +928,13 @@ Parameter x must point to valid data."""
             callback = callback._ctx[0]
         return _api.pattern_ffi_slice_delegate(callback)
 
+    def pattern_ffi_slice_delegate_huge(callback):
+        """"""
+        global _api
+        if hasattr(callback, "_ctx"):
+            callback = callback._ctx[0]
+        return _api.pattern_ffi_slice_delegate_huge(callback)
+
     def pattern_ffi_option_1(ffi_slice):
         """"""
         global _api
@@ -932,6 +956,15 @@ Parameter x must point to valid data."""
             api = api._ctx[0]
         return _api.my_api_init_v1(api)
 
+    def pattern_callback_1(callback, x):
+        """"""
+        global _api
+        if hasattr(callback, "_ctx"):
+            callback = callback._ctx[0]
+        if hasattr(x, "_ctx"):
+            x = x._ctx[0]
+        return _api.pattern_callback_1(callback, x)
+
     def pattern_service_create(context_ptr, value):
         """"""
         global _api
